require 'forwardable'

module Glomper
  class Client
    extend Forwardable
    
    # include Users
    # include Places
    
    attr_reader :client_id, :client_secret, :oauth_token
    
    def initialize(options={})
      @client_id = options[:client_id]
      @client_secret = options[:client_secret]
      @oauth_token = options[:oauth_token]
    end

    def method_missing(meth, *args, &block)
      m = meth.to_s.capitalize.to_sym
      if Glomper::API[m]
        Glomper::Request.new(self, Glomper::API[m], *args, &block)
      else
        super
      end
    end
    
    def api_url
      "http://glomper.com/api"
    end

    def return_error_or_body(response, response_body)
      response.body.meta.code == 200 ? response_body : response.body
    end        
  
    def connection
      params = {}
      params[:client_id] = @client_id if @client_id
      params[:client_secret] = @client_secret if @client_secret
      params[:access_token] = @oauth_token if @oauth_token
      @connection ||= Faraday::Connection.new(:url => api_url, :params => params, :headers => default_headers) do |builder|
        builder.adapter Faraday.default_adapter
        builder.use Faraday::Response::Mashify
        builder.use Faraday::Response::ParseJson
      end
    end

    private

      def default_headers
        headers = {
          :accept =>  'application/json',
          :user_agent => 'Ruby gem'
        }
      end  
  end
end